@@ -4,8 +4,8 @@ package Dist::Zilla::Plugin::Keywords;
 BEGIN {
   $Dist::Zilla::Plugin::Keywords::AUTHORITY = 'cpan:ETHER';
 }
-# git description: v0.003-1-g4a0135e
-$Dist::Zilla::Plugin::Keywords::VERSION = '0.004';
+# git description: v0.004-8-g709add4
+$Dist::Zilla::Plugin::Keywords::VERSION = '0.005';
 # ABSTRACT: add keywords to metadata in your distribution
 # KEYWORDS: plugin distribution metadata cpan-meta keywords
 # vim: set ts=8 sw=4 tw=78 et :
@@ -16,6 +16,7 @@ with 'Dist::Zilla::Role::MetaProvider',
 use Moose::Util::TypeConstraints;
 use MooseX::Types::Moose 'ArrayRef';
 use MooseX::Types::Common::String 'NonEmptySimpleStr';
+use Encode 'decode';
 use namespace::autoclean;
 
 my $word = subtype NonEmptySimpleStr,
@@ -43,7 +44,11 @@ has keywords => (
 sub metadata
 {
     my $self = shift;
-    return { keywords => $self->keywords };
+
+    my $keywords = $self->keywords;
+    return {
+        @$keywords ? ( keywords => $keywords ) : ()
+    };
 }
 
 sub keywords_from_file
@@ -52,15 +57,20 @@ sub keywords_from_file
 
     my $document = $self->ppi_document_for_file($file);
 
-    my @keywords;
+    my $keywords;
     $document->find(
         sub {
             die if $_[1]->isa('PPI::Token::Comment')
-                and (@keywords = $_[1]->content =~ m/^\s*#+\s*KEYWORDS:\s*(.+)$/m);
+                and ($keywords) = $_[1]->content =~ m/^\s*#+\s*KEYWORDS:\s*(.+)$/m;
         }
     );
-    $self->log('found keyword string in main module: ' . $_) foreach @keywords;
-    return map { split /\s+/ } @keywords;
+    return if not $keywords;
+
+    # TODO: skip decoding logic if/when PPI is new enough
+    $keywords = decode($file->encoding, $keywords, Encode::FB_CROAK);
+
+    $self->log('found keyword string in main module: ' . $keywords);
+    return split /\s+/, $keywords;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -71,15 +81,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Karen Etheridge irc
-
 =head1 NAME
 
 Dist::Zilla::Plugin::Keywords - add keywords to metadata in your distribution
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -120,6 +128,8 @@ scanned for the I<first> C<# KEYWORDS:> comment.
 
 =head1 SUPPORT
 
+=for stopwords irc
+
 Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Keywords>
 (or L<bug-Dist-Zilla-Plugin-Keywords@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Keywords@rt.cpan.org>).
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
